@@ -1,22 +1,28 @@
 /* error.c - Error-management and messaging routines.
  *
- * Copyright (C) 2001  Oskar Liljeblad
+ * Copyright (C) 1998-2005 Oskar Liljeblad
  *
- * This file is part of the file renaming utilities (renameutils)
- * and regex-markup.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This software is copyrighted work licensed under the terms of the
- * GNU General Public License. Please consult the file `COPYING' for
- * details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-#ifndef __ERROR_H__
-#define __ERROR_H__
+#ifndef COMMON_ERROR_H
+#define COMMON_ERROR_H
 
-/* C89 */
-#include <stdarg.h>
-#include <errno.h>		/* for errno below */
-#include <stddef.h>
+#include <stdarg.h>	/* C89 */
+#include <stddef.h>	/* C89 */
+#include <errno.h>	/* C89 */
 
 extern void (*program_termination_hook)(void);
 
@@ -37,6 +43,8 @@ void die_error(void) __attribute__ ((noreturn));
 
 void free_error(void);
 
+#define errstr strerror(errno)
+
 /**
  * @note This function is also defined in error.c
  */
