@@ -1,13 +1,20 @@
 /* io-utils.c - Various utilities dealing with files.
  *
- * Copyright (C) 2001  Oskar Liljeblad
+ * Copyright (C) 2001-2005 Oskar Liljeblad
  *
- * This file is part of the file renaming utilities (renameutils)
- * and regex-markup.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This software is copyrighted work licensed under the terms of the
- * GNU General Public License. Please consult the file `COPYING' for
- * details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #if HAVE_CONFIG_H
@@ -65,8 +72,9 @@
 #include <stdlib.h>
 #include <errno.h>
 /* gnulib */
-#include <getline.h>
-#include <xalloc.h>
+#include "getline.h"
+#include "xalloc.h"
+#include "xvasprintf.h"
 /* common */
 #include "memory.h"
 #include "strbuf.h"
@@ -81,8 +89,13 @@
 bool
 file_exists(const char *file)
 {
-	struct stat64 statbuf;
-	return (lstat64(file, &statbuf) != -1);
+#if HAVE_LSTAT64
+    struct stat64 statbuf;
+    return (lstat64(file, &statbuf) != -1);
+#else
+    struct stat statbuf;
+    return (stat(file, &statbuf) != -1);
+#endif
 }
 
 /**
@@ -194,7 +207,7 @@ backticks(const char *program, char *const args[], int *status)
 	int child_pid;
 	FILE *pipe_file;
 	char *line;
-	char *out;
+	StrBuf *out;
 
 	if (pipe(child_pipe) == -1)
 		return NULL;
@@ -223,7 +236,7 @@ backticks(const char *program, char *const args[], int *status)
 	if (out == NULL)
 		return NULL;
 	while ((line = read_line(pipe_file)) != NULL) {
-		strbuf_append(&out, line);
+		strbuf_append(out, line);
 		free(line);
 	}
 	if (errno != 0)
@@ -234,7 +247,7 @@ backticks(const char *program, char *const args[], int *status)
 	if (fclose(pipe_file) != 0)
 		return NULL;
 
-	return strbuf_free_to_string(&out);
+	return strbuf_free_to_string(out);
 }
 
 /**
