@@ -1,27 +1,40 @@
 /* llist.h - A linked list with a container object (unlike GList)
  *
- * Copyright (C) 2001  Oskar Liljeblad
+ * Copyright (C) 1998-2005 Oskar Liljeblad
  *
- * This file is part of the file renaming utilities (renameutils)
- * and regex-markup.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This software is copyrighted work licensed under the terms of the
- * GNU General Public License. Please consult the file `COPYING' for
- * details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-#ifndef __LLIST_H__
-#define __LLIST_H__
+#ifndef COMMON_LLIST_H
+#define COMMON_LLIST_H
 
-#include <sys/types.h>
-#if HAVE_STDINT_H
-#include <stdint.h>
-#endif
-#include "common.h"
-#include "iterator.h"
+#include <sys/types.h>		/* POSIX */
+#include <stdint.h>		/* POSIX/Gnulib */
+#include <stdbool.h>
 
 typedef struct _LList LList;
 typedef struct _LNode LNode;
+typedef struct _LListIterator LListIterator;
+
+struct _LListIterator {
+    bool (*has_next)(LListIterator *it);
+    void *(*next)(LListIterator *it);
+    void (*remove)(LListIterator *it);
+    void *p0;
+    void *p1;
+};
 
 LList *llist_new(void);
 void llist_free(LList *list);
@@ -36,6 +49,7 @@ void llist_clear(LList *list);
 void llist_add_at(LList *list, uint32_t index, void *object);
 void llist_add_first(LList *list, void *object);
 void llist_add_last(LList *list, void *object);
+void llist_add_all(LList *list, LList *list2);
 
 #define llist_pop		llist_remove_last
 #define llist_shift		llist_remove_first
@@ -56,8 +70,8 @@ LList *llist_clone(LList *list);
 void **llist_to_array(LList *list);
 void **llist_to_null_terminated_array(LList *list);
 
-void llist_iterate(LList *list, IteratorFunc iterator_func);
-Iterator *llist_iterator(LList *list);
+void llist_iterate(LList *list, void (*iterator_func)());
+void llist_iterator(LList *list, LListIterator *it);
 
 void llist_reverse(LList *list);
 
